#!/bin/bash

function print_usage () {
  echo "Usage: $0 [OPTION]"
	echo ""
	echo "Available Options:"
	echo "  -v, --verbose=VERBOSE    Set sensor verbosity level"
  echo "                               Level 2 - Print general information"
	echo "                               Level 3 - Print Network Events"
	echo "                               Level 4 - Port scan, Listening ports"
	echo "                               Level 5 - Print EVERY Network Event including localhost events and DNS packets"
	echo ""
  exit 1
}

DEFAULT_VERBOSE="2"

if [ $# -eq 0 ]; then
	VERBOSE=$DEFAULT_VERBOSE
else
	case "$1" in
		-v=*|--verbose=*)
			VERBOSE="${1#*=}"
			;;
		-v|--verbose)
			VERBOSE="$2"
			;;
		-h|--help)
			print_usage
			;;
		*)
			print_usage
			;;
	esac
fi

# Create link to specific kernel version
rm /lib/modules/$(uname -r) 2&> /dev/null || true
ln -s /lib/modules/4.8.0-58-generic /lib/modules/$(uname -r)

# Enable the Kernel just in time compilation feature for BPF
echo 1 > /proc/sys/net/core/bpf_jit_enable

# mount debugfs
if ! grep -qs '/sys/kernel/debug ' /proc/mounts; then
    mount -t debugfs none /sys/kernel/debug
else
    echo "Kernel debugfs already mounted."
    echo ""
fi

# Run the runtime Kubernetes sensor
/kubernetes-sensor -v $VERBOSE
